@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.040'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -95,7 +95,7 @@ Path::Naive - Yet another abstract, Unix-like path manipulation routines
 
 =head1 VERSION
 
-This document describes version 0.040 of Path::Naive (from Perl distribution Path-Naive), released on 2020-02-05.
+This document describes version 0.041 of Path::Naive (from Perl distribution Path-Naive), released on 2020-02-05.
 
 =head1 SYNOPSIS
 
@@ -115,7 +115,9 @@ This document describes version 0.040 of Path::Naive (from Perl distribution Pat
  @dirs = split_path(".././../a");     # -> ("..", ".", "..", "a")
  @dirs = split_path("a/b/c/..");      # -> ("a", "b", "c", "..")
 
- # normalize path (collapse . & .., remove double & trailing / except on "/")
+ # normalize path (collapse . & .., remove double & trailing / except on "/").
+ # note that it can return path string (in scalar context) or path elements (in
+ # list context).
  $p = normalize_path("");              # dies, empty path
  $p = normalize_path("/");             # -> "/"
  $p = normalize_path("..");            # -> ".."
@@ -127,10 +129,7 @@ This document describes version 0.040 of Path::Naive (from Perl distribution Pat
  $p = normalize_path("a/b/../");       # -> "a"
  $p = normalize_path("/a/./../b");     # -> "/b"
  $p = normalize_path("/a/../../b");    # -> "/b" (.. after hitting root is ok)
-
- # in list context, normalize_path returns list, this is useful to save you from
- # having to split the normalized path yourself.
- @p = normalize_path("a/b/./");        # -> ("a", "b")
+ @p = normalize_path("a/b/./");        # -> ("a", "b") # convenient, you don't have to split_path() separately.
 
  # check whether path is absolute (starts from root)
  say is_abs_path("/");                # -> 1
@@ -144,7 +143,7 @@ This document describes version 0.040 of Path::Naive (from Perl distribution Pat
  say is_rel_path("/");                # -> 0
  say is_rel_path("a/b");              # -> 1
 
- # concatenate two paths
+ # concatenate two paths. always return path string.
  say concat_path("a", "b");           # -> "a/b"
  say concat_path("a/", "b");          # -> "a/b"
  say concat_path("a", "b/");          # -> "a/b/"
